==> nextcloud-18.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla netinkama naudoti",
    "Unknown error" : "Nežinoma klaida",
    "All files" : "Visi failai",
    "Recent" : "Paskiausiai naudoti",
    "Favorites" : "Mėgstami",
    "File could not be found" : "Nepavyko rasti failo",
    "Move or copy" : "Perkelti ar kopijuoti",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Home" : "Pagrindinis",
    "Close" : "Užverti",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
    "Upload cancelled." : "Įkėlimo atsisakyta.",
    "Processing files …" : "Apdorojami failai…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko \"{dir}\" daugiau nebėra",
    "Not enough free space" : "Trūksta laisvos vietos",
    "An unknown error has occurred" : "Įvyko nežinoma klaida",
    "Uploading …" : "Įkeliama…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Error when assembling chunks, status code {status}" : "Klaida surenkant dalis, klaidos kodas {status}",
    "Actions" : "Veiksmai",
    "Rename" : "Pervadinti",
    "Copy" : "Kopijuoti",
    "Choose target folder" : "Pasirinkite paskirties aplanką",
    "Open" : "Atverti",
    "Delete file" : "Ištrinti failą",
    "Delete folder" : "Ištrinti aplanką",
    "Disconnect storage" : "Atjungti saugyklą",
    "Unshare" : "Nustoti bendrinti",
    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Duomenys",
    "Select" : "Pasirinkti",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, prašome peržiūrėti žurnalo įrašus arba susisiekti su administratoriumi",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Nepavyko nukopijuoti \"{file}\", toks jau yra",
    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
    "Copied {origin} inside {destination}" : "Nukopijuota {origin} aplanke {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Nukopijuota {origin} ir dar {nbfiles} failus aplanke {destination}",
    "{newName} already exists" : "{newName} jau yra",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo \"{fileName}\", jo daugiau nebėra",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Pasirinkite kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\", nes jis jau yra",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\", nes jis jau yra",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptą"],
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliamas %n failas"],
    "New" : "Naujas",
    "Select file range" : "Žymėti failų rėžį",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "{used} used" : "{used} naudojama",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nėra leidžiamas failo tipas",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\""],
    "View in folder" : "Rodyti aplanke",
    "Copied!" : "Nukopijuota!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie failo/aplanko)",
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Pažymėtas mėgstamu",
    "Favorite" : "Mėgstamas",
    "You can only favorite a single file or folder at a time" : "Vienu metu galite pažymėti mėgstamu tik vieną failą ar aplanką",
    "New folder" : "Naujas aplankas",
    "Upload file" : "Įkelti failą",
    "Not favorited" : "Nepažymėtas mėgstamu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "Added to favorites" : "Pridėta į mėgstamus",
    "Removed from favorites" : "Pašalintas iš mėgstamų",
    "You added {file} to your favorites" : "Pridėjote {file} į savo mėgstamus",
    "You removed {file} from your favorites" : "Pašalinote {file} iš mėgstamų",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "\"remote user\"" : "\"nuotolinis naudotojas\"",
    "You created {file}" : "Jūs sukūrėte {file}",
    "You created an encrypted file in {file}" : "Sukūrėte užšifruotą failą {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{user} created an encrypted file in {file}" : "{user} sukūrė užšifruotą failą {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "You changed an encrypted file in {file}" : "Pakeitėte užšifruotą failą {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "{user} changed an encrypted file in {file}" : "{user} pakeitė užšifruotą failą {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "You deleted an encrypted file in {file}" : "Jūs ištrynėte šifruotą failą {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ištrynė šifruotą failą {file}",
    "You restored {file}" : "Jūs atkūrėte {file}",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>mėgstamų</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Failas ar aplankas <strong>pakeistas</strong> ar <strong>pervadintas</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Sukurtas</strong> naujas failas ar aplankas",
    "A file or folder has been <strong>deleted</strong>" : "Failas ar aplankas <strong>ištrintas</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie jūsų <strong>mėgstamų failų</strong> sukūrimą ar pakeitimus <em>(Tik srautas)</em>",
    "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas <strong>atkurtas</strong>",
    "Unlimited" : "Neribotai",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "Accept" : "Priimti",
    "Reject" : "Atmesti",
    "Incoming ownership transfer from {user}" : "Gaunamasis nuosavybės perdavimas nuo {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ar norite priimti {path}?\n\nPastaba: Priėmus, perdavimo procesas gali užtrukti iki 1 valandos.",
    "Ownership transfer failed" : "Nuosavybės perdavimas nepavyko",
    "Ownership transfer done" : "Nuosavybės perdavimas atliktas",
    "File Management" : "Failų tvarkymas",
    "Transfer ownership of a file or folder" : "Perduoti failo ar aplanko nuosavybę",
    "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
    "Change" : "Keisti",
    "New owner" : "Naujasis savininkas",
    "Search users" : "Ieškoti naudotojų",
    "Choose a file or folder to transfer" : "Pasirinkite norimą perduoti failą ar aplanką",
    "Transfer" : "Perduoti",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Ownership transfer request sent" : "Nuosavybės perdavimo užklausa išsiųsta",
    "Tags" : "Žymės",
    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
    "%s used" : "%s panaudota",
    "%s%% of %s used" : "naudojama %s%% iš %s",
    "%1$s of %2$s used" : "naudojama %1$s iš %2$s",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naudokite šį adresą norėdami <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">gauti prieigą prie failų per WebDAV</a>",
    "Toggle grid view" : "Rodyti tinkleliu",
    "No files in here" : "Čia failų nėra",
    "Upload some content or sync with your devices!" : "Įkelkite failus arba sinchronizuokite su savo įrenginiais!",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "No favorites yet" : "Kol kas nėra mėgstamų",
    "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
    "Deleted files" : "Ištrinti failai",
    "Shares" : "Viešiniai",
    "Shared with others" : "Bendrinama su kitais",
    "Shared with you" : "Bendrinama su jumis",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "Deleted shares" : "Ištrinti viešiniai",
    "Pending shares" : "Laukiantys viešiniai",
    "Text file" : "Tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "%s of %s used" : "naudojama %s iš %s",
    "%1$s%% of %2$s used" : "%1$s naudojama %% iš %2$s"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-20.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files/l10n/lt_LT.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage invalid" : "Saugykla netinkama naudoti",
    "Unknown error" : "Nežinoma klaida",
    "File could not be found" : "Nepavyko rasti failo",
    "Move or copy" : "Perkelti ar kopijuoti",
    "Download" : "Atsisiųsti",
    "Delete" : "Ištrinti",
    "Home" : "Pagrindinis",
    "Close" : "Užverti",
    "Favorites" : "Mėgstami",
    "Could not create folder \"{dir}\"" : "Nepavyko sukurti aplanko \"{dir}\"",
    "This will stop your current uploads." : "Tai sustabdys dabartinius įkėlimus.",
    "Upload cancelled." : "Įkėlimo atsisakyta.",
    "Processing files …" : "Apdorojami failai…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nepavyksta įkelti {filename}, nes tai yra katalogas arba šio failo dydis yra 0 baitų",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nepakanka laisvos vietos. Jūs bandote įkelti {size1} dydžio bylą, bet liko tik  {size2} vietos",
    "Target folder \"{dir}\" does not exist any more" : "Paskirties aplanko \"{dir}\" daugiau nebėra",
    "Not enough free space" : "Trūksta laisvos vietos",
    "An unknown error has occurred" : "Įvyko nežinoma klaida",
    "Uploading …" : "Įkeliama…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} iš {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "To elemento įkėlimas nėra palaikomas",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Error when assembling chunks, status code {status}" : "Klaida surenkant dalis, klaidos kodas {status}",
    "Actions" : "Veiksmai",
    "Rename" : "Pervadinti",
    "Copy" : "Kopijuoti",
    "Choose target folder" : "Pasirinkite paskirties aplanką",
    "Open" : "Atverti",
    "Delete file" : "Ištrinti failą",
    "Delete folder" : "Ištrinti aplanką",
    "Disconnect storage" : "Atjungti saugyklą",
    "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui \"{file}\"",
    "Files" : "Failai",
    "Details" : "Duomenys",
    "Select" : "Pasirinkti",
    "Pending" : "Laukiantis",
    "Unable to determine date" : "Nepavyksta nustatyti datos",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, peržiūrėkite žurnalo įrašus arba susisiekite su administratoriumi",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau egzistuoja",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "copy" : "kopija",
    "Could not copy \"{file}\", target exists" : "Nepavyko nukopijuoti \"{file}\", toks jau yra",
    "Could not copy \"{file}\"" : "Nepavyko nukopijuoti \"{file}\"",
    "Copied {origin} inside {destination}" : "Nukopijuota {origin} aplanke {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Nukopijuota {origin} ir dar {nbfiles} failus aplanke {destination}",
    "{newName} already exists" : "{newName} jau yra",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nepavyko pervadinti failo \"{fileName}\", jo daugiau nebėra",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas \"{targetName}\" jau naudojamas aplanke \"{dir}\". Pasirinkite kitokį pavadinimą.",
    "Could not rename \"{fileName}\"" : "Nepavyko pervadinti failo \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\", nes jis jau yra",
    "Could not create folder \"{dir}\" because it already exists" : "Nepavyko sukurti aplanko \"{dir}\", nes jis jau yra",
    "Could not fetch file details \"{file}\"" : "Nepavyko gauti išsamesnės failo \"{file}\" informacijos",
    "Error deleting file \"{fileName}\"." : "Klaida trinant failą \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Kituose aplankuose nėra paieškos rezultatų, skirtų {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Įveskite daugiau nei du simbolius, jei norite ieškoti kituose aplankuose",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
    "{dirs} and {files}" : "{dirs} ir {files}",
    "_including %n hidden_::_including %n hidden_" : ["įskaitant %n paslėptą","įskaitant %n paslėptus","įskaitant %n paslėptų","įskaitant %n paslėptą"],
    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
    "_Uploading %n file_::_Uploading %n files_" : ["Įkeliamas %n failas","Įkeliami %n failai","Įkeliama %n failų","Įkeliamas %n failas"],
    "New" : "Naujas",
    "Select file range" : "Žymėti failų rėžį",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "{used} used" : "{used} naudojama",
    "\"{name}\" is an invalid file name." : "„{name}“ yra netinkamas bylos pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nėra leidžiamas failo tipas",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} saugykla yra pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "_matches '{filter}'_::_match '{filter}'_" : ["atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\"","atitinka \"{filter}\""],
    "View in folder" : "Rodyti aplanke",
    "Copied!" : "Nukopijuota!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie failo/aplanko)",
    "Path" : "Kelias",
    "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
    "Favorited" : "Pažymėtas mėgstamu",
    "Favorite" : "Mėgstamas",
    "You can only favorite a single file or folder at a time" : "Vienu metu galite pažymėti mėgstamu tik vieną failą ar aplanką",
    "New folder" : "Naujas aplankas",
    "Upload file" : "Įkelti failą",
    "Recent" : "Paskiausiai naudoti",
    "Not favorited" : "Nepažymėtas mėgstamu",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "An error occurred while trying to update the tags" : "Bandant atnaujinti žymes įvyko klaida",
    "Added to favorites" : "Pridėta į mėgstamus",
    "Removed from favorites" : "Pašalintas iš mėgstamų",
    "You added {file} to your favorites" : "Pridėjote {file} į savo mėgstamus",
    "You removed {file} from your favorites" : "Pašalinote {file} iš mėgstamų",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "\"remote user\"" : "\"nuotolinis naudotojas\"",
    "You created {file}" : "Jūs sukūrėte {file}",
    "You created an encrypted file in {file}" : "Sukūrėte užšifruotą failą {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{user} created an encrypted file in {file}" : "{user} sukūrė užšifruotą failą {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "You changed an encrypted file in {file}" : "Pakeitėte užšifruotą failą {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "{user} changed an encrypted file in {file}" : "{user} pakeitė užšifruotą failą {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "You deleted an encrypted file in {file}" : "Jūs ištrynėte šifruotą failą {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ištrynė šifruotą failą {file}",
    "You restored {file}" : "Jūs atkūrėte {file}",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>mėgstamų</strong>",
    "A file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> failas ar aplankas",
    "A favorite file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> mėgstamas failas ar aplankas",
    "All files" : "Visi failai",
    "Unlimited" : "Neribotai",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "Accept" : "Priimti",
    "Reject" : "Atmesti",
    "Incoming ownership transfer from {user}" : "Gaunamasis nuosavybės perdavimas nuo {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ar norite priimti {path}?\n\nPastaba: Priėmus, perdavimo procesas gali užtrukti iki 1 valandos.",
    "Ownership transfer failed" : "Nuosavybės perdavimas nepavyko",
    "Your ownership transfer of {path} to {user} failed." : "Nepavyko perduoti jūsų {path} nuosavybės naudotojui {user}.",
    "The ownership transfer of {path} from {user} failed." : "{path} nuosavybės perdavimas iš naudotojo {user} nepavyko.",
    "Ownership transfer done" : "Nuosavybės perdavimas atliktas",
    "Your ownership transfer of {path} to {user} has completed." : "Jūsų {path} nuosavybės perdavimas naudotojui {user} užbaigtas.",
    "The ownership transfer of {path} from {user} has completed." : "{path} nuosavybės perdavimas iš naudotojo {user} užbaigtas.",
    "in %s" : "per %s",
    "File Management" : "Failų tvarkymas",
    "Transfer ownership of a file or folder" : "Perduoti failo ar aplanko nuosavybę",
    "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
    "Change" : "Keisti",
    "New owner" : "Naujasis savininkas",
    "Search users" : "Ieškoti naudotojų",
    "Choose a file or folder to transfer" : "Pasirinkite norimą perduoti failą ar aplanką",
    "Transfer" : "Perduoti",
    "Transfer {path} to {userid}" : "Perduoti {path} naudotojui {userid}",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Ownership transfer request sent" : "Nuosavybės perdavimo užklausa išsiųsta",
    "Cannot transfer ownership of a file or folder you don't own" : "Negalima perduoti, failo aplanko, kuris jums nepriklauso, nuosavybės",
    "Tags" : "Žymės",
    "Unable to change the favourite state of the file" : "Nepavyksta pakeisti failo Lankomiausiųjų būsenos",
    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
    "%s used" : "%s panaudota",
    "%s%% of %s used" : "naudojama %s%% iš %s",
    "%1$s of %2$s used" : "naudojama %1$s iš %2$s",
    "Settings" : "Nustatymai",
    "Show hidden files" : "Rodyti paslėptus failus",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Naudokite šį adresą norėdami pasiekti failus per WebDAV",
    "Toggle grid view" : "Rodyti tinkleliu",
    "No files in here" : "Čia failų nėra",
    "Upload some content or sync with your devices!" : "Įkelkite failus arba sinchronizuokite su savo įrenginiais!",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "No favorites yet" : "Kol kas nėra mėgstamų",
    "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
    "Deleted files" : "Ištrinti failai",
    "Shares" : "Viešiniai",
    "Shared with others" : "Bendrinama su kitais",
    "Shared with you" : "Bendrinama su jumis",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "Deleted shares" : "Ištrinti viešiniai",
    "Pending shares" : "Laukiantys viešiniai",
    "Text file" : "Tekstinis failas",
    "New text file.txt" : "Naujas tekstinis failas.txt",
    "Unshare" : "Nustoti bendrinti",
    "This group folder is full, files can not be updated or synced anymore!" : "Šis grupės aplankas yra pilnas, failai daugiau nebegali būti atnaujinti ar sinchronizuoti!",
    "This external storage is full, files can not be updated or synced anymore!" : "Ši išorinė saugykla yra pilna, failai daugiau nebegali būti atnaujinti ar sinchronizuoti!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} saugykla yra beveik pilna ({usedSpacePercent}%)",
    "This group folder is almost full ({usedSpacePercent}%)" : "Šis grupės aplankas yra beveik pilnas ({usedSpacePercent}%)",
    "This external storage is almost full ({usedSpacePercent}%)" : "Ši išorinė saugykla yra beveik pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Failas ar aplankas <strong>pakeistas</strong> ar <strong>pervadintas</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Sukurtas</strong> naujas failas ar aplankas",
    "A file or folder has been <strong>deleted</strong>" : "Failas ar aplankas <strong>ištrintas</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Riboti pranešimus apie jūsų <strong>mėgstamų failų</strong> sukūrimą ar pakeitimus <em>(Tik srautas)</em>",
    "A file or folder has been <strong>restored</strong>" : "Failas ar aplankas <strong>atkurtas</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Negalima perduoti, failo aplanko, kuris jums nepriklauso, nuosavybės",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Naudokite šį adresą norėdami <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">gauti prieigą prie failų per WebDAV</a>"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
